@@ -1,8 +1,13 @@
+import os
 from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Tuple
 
 from gradio import utils
 from gradio.context import Context
 from gradio.launchable import Launchable
+from gradio.routes import PredictBody
+
+if TYPE_CHECKING:  # Only import for type checking (is False at runtime).
+    from gradio.component import Component
 
 
 class Block:
@@ -30,6 +35,66 @@ class Block:
             }
         )
 
+    def change(
+        self, fn: str, inputs: List["Component"], outputs: List["Component"]
+    ) -> None:
+        """
+        Adds change event to the component's dependencies.
+
+        Whenever the component changes the function is triggered.
+
+        Parameters:
+            fn: function name
+            inputs: input list
+            outputs: output list
+
+        Returns: None
+
+        """
+        if not isinstance(inputs, list):
+            inputs = [inputs]
+        if not isinstance(outputs, list):
+            outputs = [outputs]
+        Context.root_block.fns.append(fn)
+        Context.root_block.dependencies.append(
+            {
+                "targets": [self._id],
+                "trigger": "change",
+                "inputs": [block._id for block in inputs],
+                "outputs": [block._id for block in outputs],
+            }
+        )
+
+    def save(
+        self, fn: str, inputs: List["Component"], outputs: List["Component"]
+    ) -> None:
+        """
+        Adds save event to the component's dependencies.
+
+        Whenever the component is saved the function is triggered.
+
+        Parameters:
+            fn: function name
+            inputs: input list
+            outputs: output list
+
+        Returns: None
+
+        """
+        if not isinstance(inputs, list):
+            inputs = [inputs]
+        if not isinstance(outputs, list):
+            outputs = [outputs]
+        Context.root_block.fns.append(fn)
+        Context.root_block.dependencies.append(
+            {
+                "targets": [self._id],
+                "trigger": "save",
+                "inputs": [block._id for block in inputs],
+                "outputs": [block._id for block in outputs],
+            }
+        )
+
 
 class BlockContext(Block):
     def __init__(self):
@@ -73,6 +138,8 @@ class Blocks(Launchable, BlockContext):
         self.theme = theme
         self.requires_permissions = False  # TODO: needs to be implemented
         self.enable_queue = False
+        self.is_space = True if os.getenv("SYSTEM") == "spaces" else False
+        self.stateful = False  # TODO: implement state
 
         super().__init__()
         Context.root_block = self
@@ -80,9 +147,9 @@ class Blocks(Launchable, BlockContext):
         self.fns = []
         self.dependencies = []
 
-    def process_api(self, data: Dict[str, Any], username: str = None) -> Dict[str, Any]:
-        raw_input = data["data"]
-        fn_index = data["fn_index"]
+    def process_api(self, data: PredictBody, username: str = None) -> Dict[str, Any]:
+        raw_input = data.data
+        fn_index = data.fn_index
         fn = self.fns[fn_index]
         dependency = self.dependencies[fn_index]
 
