@@ -294,7 +294,7 @@ def get_spaces_interface(model_name, api_key, alias):
 
     r = requests.get(iframe_url)
     result = re.search(
-        "window.gradio_config = (.*?);</script>", r.text
+        r"window.gradio_config = (.*?);[\s]*</script>", r.text
     )  # some basic regex to extract the config
     try:
         config = json.loads(result.group(1))
