@@ -88,7 +88,7 @@ class TestDemo(unittest.TestCase):
             EC.presence_of_element_located(
                 (
                     By.CSS_SELECTOR,
-                    ".panel:nth-child(1) .component:nth-child(1) .input_text textarea",
+                    ".panel:nth-child(1) .component:nth-child(1) .input-text",
                 )
             )
         )
@@ -98,7 +98,7 @@ class TestDemo(unittest.TestCase):
             EC.presence_of_element_located(
                 (
                     By.CSS_SELECTOR,
-                    ".panel:nth-child(1) .component:nth-child(2) .input_text textarea",
+                    ".panel:nth-child(1) .component:nth-child(2) .input-text",
                 )
             )
         )
@@ -122,7 +122,10 @@ class TestDemo(unittest.TestCase):
             time.sleep(0.2)
             total_sleep += 0.2
 
-        self.assertEqual(elem.text, "L+e+W-a-n-t'+s+ t-g+o see a magic trick?-!+")
+        self.assertEqual(
+            elem.text,
+            "L + e + W - a - n - t ' + s + t - g + o s e e a m a g i c t r i c k ? - ! +",
+        )
         golden_img = os.path.join(
             current_dir, GOLDEN_PATH.format("diff_texts", "magic_trick")
         )
@@ -141,7 +144,7 @@ class TestDemo(unittest.TestCase):
             EC.presence_of_element_located(
                 (
                     By.CSS_SELECTOR,
-                    ".panel:nth-child(1) .component:nth-child(1) .hidden_upload",
+                    ".panel:nth-child(1) .component:nth-child(1) .hidden-upload",
                 )
             )
         )
@@ -162,7 +165,7 @@ class TestDemo(unittest.TestCase):
             EC.visibility_of_element_located(
                 (
                     By.CSS_SELECTOR,
-                    ".panel:nth-child(2) .component:nth-child(2) .output_image",
+                    ".panel:nth-child(2) .component:nth-child(2) .output-image",
                 )
             )
         )
@@ -179,7 +182,7 @@ class TestDemo(unittest.TestCase):
             EC.presence_of_element_located(
                 (
                     By.CSS_SELECTOR,
-                    ".panel:nth-child(1) .component:nth-child(1) .input_text textarea",
+                    ".panel:nth-child(1) .component:nth-child(1) .input-text",
                 )
             )
         )
@@ -192,7 +195,7 @@ class TestDemo(unittest.TestCase):
             EC.presence_of_element_located(
                 (
                     By.CSS_SELECTOR,
-                    ".panel:nth-child(2) .component:nth-child(2) .output_class_without_confidences",
+                    ".panel:nth-child(2) .component:nth-child(2) .output-class",
                 )
             )
         )
@@ -224,7 +227,7 @@ class TestDemo(unittest.TestCase):
             EC.presence_of_element_located(
                 (
                     By.CSS_SELECTOR,
-                    ".panel:nth-child(2) .component:nth-child(2) .output_text",
+                    ".panel:nth-child(2) .component:nth-child(2) .output-text",
                 )
             )
         )
